Learn R Programming

sybilSBML (version 2.0.7)

getSBMLSpeciesList: Get Species List

Description

Retrieve list of species included in a SBML model

Usage

getSBMLSpeciesList(sbmlm)

Arguments

sbmlm
An object of class sbmlPtr as returned by getSBMLmodel. This is basically a pointer to a SBML model.

Value

  • If the SBML model contains a ListOfSpecies section, a list is returned:
  • idcharacter vector containing the species id's. If no id is given for a particular species, the corresponding value is set to "no_id".
  • namecharacter vector containing the species names. If not available, the value is set to the empty string "".
  • compartmentcharacter vector containing the species compartments. If not available, the value is set to the empty string "".
  • chargeinteger vector containing the charge of the species. If no charge is given for a particular species, the corresponding value is set to 0.
  • boundaryConditionlogical vector containing the boundaryCondition flag of the species. If no boundaryCondition flag is given for a particular species, the corresponding value is set to FALSE.
  • All list elements have the same length. If the SBML model does not contain a ListOfSpecies section, NULL is returned.

References

Bornstein, B. J., Keating, S. M., Jouraku, A., and Hucka M. (2008) LibSBML: An API Library for SBML. Bioinformatics 24, 880--881.

See Also

getSBMLmodel, sbmlPtr