encoding
UTF-8newcommand
{http://CRAN.R-project.org/package=#1{#1}}Changes in version 1.1.15 2012-10-15{
- updated package vignette
- slot
rhsof classmodelorgis not set
}Changes in version 1.1.14 2012-04-20{
- fileNEWSis now ininst/NEWS.Rd
- removed arguments
verboseMode,loglevel,logfileandlogfileEncfrom functionreadSBMLmod; use functionsinkinstead - fixed a bug in
.uglyHack: tries no longer to fix SBMLWarnings,
which is not necessary .uglyHackusestempfile()to generate corrected
SBML files- fixed a bug in
readSBMLmod(): slotsubSyswas not of
correct data type in rare cases - better SBML id formatting in
readSBMLmod()
}Changes in version 1.1.13 2012-03-16{
- compatible withsybilversion 0.5.12: replacedSparseMwithMatrix
- some additions to
.uglyHack() - fixed a small bug in
readSBMLmod(), when parsing sub systems
}Changes in version 1.1.12 2011-12-12{
- fixed a small bug in
readSBMLmod()concerning the detection of
gpr rules - fixed a bug in
readSBMLmod(): genes from reactions which
are excluded from the model are not read
}Changes in version 1.1.11 2011-12-09{
- very minor adjustments in
readSBMLmod() readSBMLmod()will continue reading the model,
ifrsbmlproduces warnings. Check warnings in the log file;
argumentsloglevelandlogfileinreadSBMLmod()
}Changes in version 1.1.10 2011-08-30{
}Changes in version 1.1.9 2011-08-30{
- added boolean arguments
remMet,contrMet,singletonMetanddeadEndmettoreadSBMLmod(),
the two boolen argumentsremSingleMetandconstrSingleMetare removed, seehelp("readSBMLmod")for details
}Changes in version 1.1.8 2011-08-15{
- some small changes according tocodetools
- slots
met_singleandreact_singleof classmodelorgare initialized withNA, notFALSE
}Changes in version 1.1.7 2011-08-12{
- new arguments for
readSBMLmod():mergeMet,balanceReact,remUnusedMetReact,remSingleMet,constrSingleMetandtol.
Seehelp("readSBMLmod")for details
}Changes in version 1.1.6 2011-08-08{
- a warning is produced, if a metabolite is used only once in S
}Changes in version 1.1.5 2011-08-08{
readSBMLmod()removes unused metabolites and reactions
(rows and lines without any non-zero entries)readSBMLmod()merges and balances metabolites as inreadTSVmod()fromsybil
}Changes in version 1.1.4 2011-08-05{
- fixed a bug in
readSBMLmod()concerning the number of
metabolite names and metabolite compartments
}Changes in version 1.1.3 2011-08-05{
- added
NAMESPACE - new boolean parameter
bndCndinreadSBMLmod():
If set toTRUE, external metabolites are those,
having the SBML tagboundaryConditionset toTRUE.
If set toFALSE, external metabolites are recogized viaextMetFlag - usage of class
sybilLoginreadSBMLmod()with four new
parameters. Seehelp("readSBMLmod")for details.
}Changes in version 1.1.2 2011-07-20{
- fixed a bug in
readSBMLmod():
if an external metabolite id is removed and it occcurs in
a reaction, that particular reaction is read correctly.
}Changes in version 1.1.1 2011-07-06{
- new boolean parameter
ignoreNoAninreadSBMLmod():
if set toTRUE, any notes and annotation fields in thelistOfReactionsin an SBML file are ignored
(default:TRUE). - unused metabolites having no non-zero entry in S, are removed from S
and the metabolites list in instances of class
modelorg
}Changes in version 1.1.0 2011-05-17{
}Changes in version 1.0.3 2011-05-11{
- added compatibility tosybilversion$\geq$0.4.1:
slot
subSysis now of classmatrix - fixed a bug in
readSBMLmod(): metablite id's differing
only in the number of consecutive '_' are now recogized
as different metabolite id's. readSBMLmod()can now read the Yeast model in the fileSc_iND750_GlcMM.xmlfrom the Palsson group.
}Changes in version 1.0.2 2011-03-02{
- If the SBML file contains reactions with metabolites used as
reactands and products at the same time, the stoichiometric
coefficient for those metabolites is the sum of reactand and product.
}Changes in version 1.0.1 2011-03-01{
- fixed some regular expressions when parsing metabolite names and id's
- added argument
extMetFlagwhich is used to identify external
metabolites - reads subsystem information also from annotations
}Changes in version 1.0.0 2011-01-25{
}