getSBMLCompartList: Get Compartment List
Description
Retrieve list of compartments included in a SBML modelUsage
getSBMLCompartList(sbmlm)
Arguments
sbmlm
An object of class sbmlPtr as returned by
getSBMLmodel. This is basically a pointer to a SBML model. Value
- If the SBML model contains a ListOfCompartments section, a
list is
returned: - idcharacter vector containing the compartment id's. If no id is given for a
particular compartment, the corresponding value is set to
"no_id". - outsidecharacter vector containing the outside argument of the compartments. If
not available, the value is set to the empty string
"". - All list elements have the same length.
If the SBML model does not contain a ListOfCompartments section,
NULL
is returned.
References
Bornstein, B. J., Keating, S. M., Jouraku, A., and Hucka M. (2008)
LibSBML: An API Library for SBML. Bioinformatics 24,
880--881.